@@ -15,7 +15,7 @@ mod relocation;
 mod section;
 mod signed;
 
-pub use agreement::{DkgFailureSig, DkgFailureSigSet, DkgKey, Proposal, SectionSigned};
+pub use agreement::{DkgFailureSig, DkgFailureSigSet, DkgKey, Proposal, SectionAuth};
 pub use join::{JoinRejectionReason, JoinRequest, JoinResponse, ResourceProofResponse};
 pub use join_as_relocated::{JoinAsRelocatedRequest, JoinAsRelocatedResponse};
 pub use network::{Network, OtherSection};
@@ -28,7 +28,9 @@ pub use section::Peer;
 pub use section::{Section, SectionPeers};
 pub use signed::{KeyedSig, SigShare};
 
-use crate::messaging::{data::DataMsg, DataSigned, EndUser, MessageId, SectionAuthorityProvider};
+use crate::messaging::{
+    data::ServiceMsg, EndUser, MessageId, SectionAuthorityProvider, ServiceAuth,
+};
 use bls::PublicKey as BlsPublicKey;
 use bls_dkg::key_gen::message::Message as DkgMessage;
 use itertools::Itertools;
@@ -42,18 +44,18 @@ use xor_name::XorName;
 /// Message sent over the among nodes
 pub enum NodeMsg {
     /// Forward a data message.
-    ForwardDataMsg {
+    ForwardServiceMsg {
         /// The msg
-        msg: DataMsg,
+        msg: ServiceMsg,
         /// The origin
         user: EndUser,
         /// Signature provided by the requester.
-        data_signed: DataSigned,
+        auth: ServiceAuth,
     },
     /// Inform other sections about our section or vice-versa.
     SectionKnowledge {
         /// `SectionAuthorityProvider` and `SecuredLinkedList` of the sender's section, with the proof chain.
-        src_info: (SectionSigned<SectionAuthorityProvider>, SecuredLinkedList),
+        src_info: (SectionAuth<SectionAuthorityProvider>, SecuredLinkedList),
         /// Message
         msg: Option<Box<NodeMsg>>,
     },
