@@ -6,7 +6,7 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use super::{agreement::SectionSigned, signed::KeyedSig};
+use super::{agreement::SectionAuth, signed::KeyedSig};
 use crate::{messaging::SectionAuthorityProvider, types::PrefixMap};
 use serde::{Deserialize, Serialize};
 use std::borrow::Borrow;
@@ -23,7 +23,7 @@ pub struct Network {
 #[derive(Clone, Eq, PartialEq, Hash, Debug, Serialize, Deserialize)]
 pub struct OtherSection {
     /// Section authority so we know this info was valid
-    pub section_auth: SectionSigned<SectionAuthorityProvider>,
+    pub section_auth: SectionAuth<SectionAuthorityProvider>,
     /// If this is signed by our section, then `key_sig` is `None`. If this is signed by our
     /// sibling section, then `key_sig` contains the proof of the signing key itself signed by our
     /// section.
